@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-hl-indent-scope
-;; Package-Version: 20250918.35
-;; Package-Revision: a6511fde03b7
+;; Package-Version: 20251030.2358
+;; Package-Revision: db541c9f24d0
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -86,9 +86,11 @@ Otherwise you must configure `hl-indent-scope-show-block-fn' yourself."
 
 ;; Automatically initialized unless already defined.
 (defface hl-indent-scope-odd-face (list (list t))
-  "Face used for odd columns.")
+  "Face used for odd columns."
+  :group 'hl-indent-scope)
 (defface hl-indent-scope-even-face (list (list t))
-  "Face used for even columns.")
+  "Face used for even columns."
+  :group 'hl-indent-scope)
 
 
 ;; ---------------------------------------------------------------------------
